@@ -1,4 +1,4 @@
 from .client import MASZClient
-from .console import MASZLogLevel
+from .console import MASZLogLevel, console
 from .obj import *
 from .exceptions import *
